==> lhcsmapi-1.1.185.tar.gz: lhcsmapi-1.1.185/lhcsmapi/gui/qh/QuerySaveBaseModule.py <==
from ipywidgets import Layout, Box, Button, Label, IntProgress
import functools

from ...dbsignal.Signal import Signal
from ...dbsignal.SignalUtilities import SignalUtilities
from ...Time import Time
from ...gui.BaseModule import BaseModule
from ...gui.qh.QhBrowserAction import QhBrowserAction
from ...metadata import SignalMetadata


class QuerySaveBaseModule(BaseModule):

    def __init__(self):
        self.btn_query = Button(description="Query", layout=Layout(width='15%'))
        self.btn_query.on_click(functools.partial(QuerySaveBaseModule.on_btn_querry_clicked, self=self))

        self.btn_save = Button(description="Save to csv", layout=Layout(width='15%'))
        self.btn_save.on_click(functools.partial(QuerySaveBaseModule.on_btn_save_clicked, self=self))

        self.lbl_query = Label(value='Press [Query] to load selected quench heater')
        self.progress_query = IntProgress(value=0, min=0, step=1, bar_style='success', orientation='horizontal',
                                          layout=Layout(width='20%'))

        self.index_output = 0

        self.widget = Box(children=[self.btn_query, self.btn_save, self.lbl_query, self.progress_query])

    def get_query_list(self):
        return self.query_list

    @staticmethod
    def on_btn_querry_clicked(b, self):
        self.mediator.notify(self, QhBrowserAction.QUERY_BUTTON_CLICKED)

    def query_signals(self, state, discharges):
        signal_types = SignalMetadata.getVariableNames(state.cir, state.cirname, state.sys, state.db)
        signal_names = [sig for signal_type in signal_types for sig in
                        SignalMetadata.getVariableName(state.cir, state.cirname, state.sys, state.db, signal_type)]
        pm_metadata = SignalMetadata.getCircuitVariableDatabaseMetadata(state.cir, state.cirname, state.sys, state.db)
        system, class_name = pm_metadata["system"], pm_metadata["className"]

        self.progress_query.max = len(discharges)
        self.progress_query.description = f'0/{len(discharges)}'

        query_list = []
        for index, row in discharges.iterrows():
            # fetch the timestamp and source
            timestamp = row['timestamp']
            source = row['magnet']

            # on query start
            self.lbl_query.value = f'Querying QH signals of {source} at {timestamp} ({Time.convertToString(timestamp)}), please wait...'

            # query execution
            qh = QuerySaveBaseModule.query_multiple_pm_signals(system, class_name, source, timestamp, signal_names)
            query_list.append(SignalUtilities.convertIndicesToSeconds(qh.getSynchronizedTimeDataframe(), unit='ns'))

            # on query complete
            self.progress_query.value = index + 1
            self.progress_query.description = f'{index+1}/{len(discharges)}'

        self.lbl_query.value = 'Query completed.'
        return query_list

    @staticmethod
    def query_multiple_pm_signals(system, class_name, source, timestamp, signal_names):
        pm_signal = Signal()
        for signal_name in signal_names:
            pm_signal.read('pm', append=True, system=system, className=class_name, source=source,
                           signalName=signal_name, eventTime=timestamp)
        return pm_signal

    @staticmethod
    def on_btn_save_clicked(b, self):
        self.mediator.notify(self, QhBrowserAction.SAVE_BUTTON_CLICKED)

    def save_queries(self, query_list, discharges):
        self.progress_query.max = len(query_list)
        for i, sl in enumerate(query_list):
            source = discharges.loc[i]['magnet']
            timestamp = discharges.loc[i]['timestamp']
            file_name = f'{self.index_output}_{source}_{int(timestamp)}.csv'
            query_list[i].to_csv(file_name)
            self.progress_query.value = i + 1
            self.progress_query.description = f'{i+1}/{len(query_list)}'
            self.index_output += 1

==> lhcsmapi-1.2.19.tar.gz: lhcsmapi-1.2.19/lhcsmapi/gui/qh/QuerySaveBaseModule.py <==
from ipywidgets import Layout, Box, Button, Label, IntProgress
import functools

from ...dbsignal.Signal import Signal
from ...dbsignal.SignalUtilities import SignalUtilities
from ...Time import Time
from ...gui.BaseModule import BaseModule
from ...gui.qh.QhBrowserAction import QhBrowserAction
from ...metadata import SignalMetadata


class QuerySaveBaseModule(BaseModule):

    def __init__(self):
        self.btn_query = Button(description="Query", layout=Layout(width='15%'))
        self.btn_query.on_click(functools.partial(QuerySaveBaseModule.on_btn_querry_clicked, self=self))

        self.btn_save = Button(description="Save to csv", layout=Layout(width='15%'))
        self.btn_save.on_click(functools.partial(QuerySaveBaseModule.on_btn_save_clicked, self=self))

        self.lbl_query = Label(value='Press [Query] to load selected quench heater')
        self.progress_query = IntProgress(value=0, min=0, step=1, bar_style='success', orientation='horizontal',
                                          layout=Layout(width='20%'))

        self.index_output = 0

        self.widget = Box(children=[self.btn_query, self.btn_save, self.lbl_query, self.progress_query])

    def get_query_list(self):
        return self.query_list

    @staticmethod
    def on_btn_querry_clicked(b, self):
        self.mediator.notify(self, QhBrowserAction.QUERY_BUTTON_CLICKED)

    def query_signals(self, state, discharges):
        signal_types = SignalMetadata.getVariableNames(state.cir, state.cirname, state.sys, state.db)
        signal_names = [sig for signal_type in signal_types for sig in
                        SignalMetadata.getVariableName(state.cir, state.cirname, state.sys, state.db, signal_type)]
        pm_metadata = SignalMetadata.getCircuitVariableDatabaseMetadata(state.cir, state.cirname, state.sys, state.db)
        system, class_name = pm_metadata["system"], pm_metadata["className"]

        self.progress_query.max = len(discharges)
        self.progress_query.description = f'0/{len(discharges)}'

        query_list = []
        for index, row in discharges.iterrows():
            # fetch the timestamp and source
            timestamp = row['timestamp']
            source = row['magnet']

            # on query start
            self.lbl_query.value = f'Querying QH signals of {source} at {timestamp} ({Time.to_string(timestamp)}), please wait...'

            # query execution
            qh = QuerySaveBaseModule.query_multiple_pm_signals(system, class_name, source, timestamp, signal_names)
            query_list.append(SignalUtilities.convert_indices_to_sec(qh.get_synchronized_time_df(), unit='ns'))

            # on query complete
            self.progress_query.value = index + 1
            self.progress_query.description = f'{index+1}/{len(discharges)}'

        self.lbl_query.value = 'Query completed.'
        return query_list

    @staticmethod
    def query_multiple_pm_signals(system, class_name, source, timestamp, signal_names):
        pm_signal = Signal()
        for signal_name in signal_names:
            pm_signal.read('pm', append=True, system=system, className=class_name, source=source,
                           signal=signal_name, eventTime=timestamp)
        return pm_signal

    @staticmethod
    def on_btn_save_clicked(b, self):
        self.mediator.notify(self, QhBrowserAction.SAVE_BUTTON_CLICKED)

    def save_queries(self, query_list, discharges):
        self.progress_query.max = len(query_list)
        for i, sl in enumerate(query_list):
            source = discharges.loc[i]['magnet']
            timestamp = discharges.loc[i]['timestamp']
            file_name = f'{self.index_output}_{source}_{int(timestamp)}.csv'
            query_list[i].to_csv(file_name)
            self.progress_query.value = i + 1
            self.progress_query.description = f'{i+1}/{len(query_list)}'
            self.index_output += 1
